pub struct AlterDatabaseStatement { /* private fields */ }Expand description
ALTER DATABASE statement builder
This struct provides a fluent API for constructing ALTER DATABASE queries. It supports standard PostgreSQL operations and CockroachDB-specific multi-region configuration.
Examples
use reinhardt_query::prelude::*;
// ALTER DATABASE mydb RENAME TO newdb
let query = Query::alter_database()
.name("mydb")
.rename_to("newdb");
// ALTER DATABASE mydb ADD REGION "us-east-1" (CockroachDB)
let query = Query::alter_database()
.name("mydb")
.add_region("us-east-1");
// ALTER DATABASE mydb PRIMARY REGION "us-east-1" (CockroachDB)
let query = Query::alter_database()
.name("mydb")
.set_primary_region("us-east-1");Implementations
Sourceimpl AlterDatabaseStatement
impl AlterDatabaseStatement
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new ALTER DATABASE statement
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_database();Sourcepub fn take(&mut self) -> Self
pub fn take(&mut self) -> Self
Take the ownership of data in the current AlterDatabaseStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut Selfwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut Selfwhere
N: IntoIden,
Set the database name
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_database()
.name("mydb");Sourcepub fn rename_to<N>(&mut self, new_name: N) -> &mut Selfwhere
N: IntoIden,
pub fn rename_to<N>(&mut self, new_name: N) -> &mut Selfwhere
N: IntoIden,
Rename the database to a new name
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_database()
.name("old_db")
.rename_to("new_db");Sourcepub fn owner_to<O>(&mut self, new_owner: O) -> &mut Selfwhere
O: IntoIden,
pub fn owner_to<O>(&mut self, new_owner: O) -> &mut Selfwhere
O: IntoIden,
Change the owner of the database
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_database()
.name("mydb")
.owner_to("new_owner");Sourcepub fn add_region<S>(&mut self, region: S) -> &mut Self
pub fn add_region<S>(&mut self, region: S) -> &mut Self
Add a region to the database (CockroachDB-specific)
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_database()
.name("mydb")
.add_region("us-east-1");Sourcepub fn drop_region<S>(&mut self, region: S) -> &mut Self
pub fn drop_region<S>(&mut self, region: S) -> &mut Self
Drop a region from the database (CockroachDB-specific)
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_database()
.name("mydb")
.drop_region("us-west-1");Sourcepub fn set_primary_region<S>(&mut self, region: S) -> &mut Self
pub fn set_primary_region<S>(&mut self, region: S) -> &mut Self
Set the primary region for the database (CockroachDB-specific)
Examples
use reinhardt_query::prelude::*;
let query = Query::alter_database()
.name("mydb")
.set_primary_region("us-east-1");Sourcepub fn configure_zone(&mut self, zone: ZoneConfig) -> &mut Self
pub fn configure_zone(&mut self, zone: ZoneConfig) -> &mut Self
Configure zone settings for the database (CockroachDB-specific)
Examples
use reinhardt_query::prelude::*;
use reinhardt_query::types::ZoneConfig;
let zone = ZoneConfig::new()
.num_replicas(3)
.add_constraint("+region=us-east-1");
let query = Query::alter_database()
.name("mydb")
.configure_zone(zone);Trait Implementations
Sourceimpl Clone for AlterDatabaseStatement
impl Clone for AlterDatabaseStatement
Sourcefn clone(&self) -> AlterDatabaseStatement
fn clone(&self) -> AlterDatabaseStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlterDatabaseStatement
impl Debug for AlterDatabaseStatement
Sourceimpl Default for AlterDatabaseStatement
impl Default for AlterDatabaseStatement
Sourceimpl QueryStatementBuilder for AlterDatabaseStatement
impl QueryStatementBuilder for AlterDatabaseStatement
Sourcefn build_any(&self, query_builder: &dyn QueryBuilderTrait) -> (String, Values)
fn build_any(&self, query_builder: &dyn QueryBuilderTrait) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for AlterDatabaseStatement