DropViewStatement

Struct DropViewStatement 

pub struct DropViewStatement { /* private fields */ }
DROP VIEW statement builder

This struct provides a fluent API for constructing DROP VIEW queries.

Examples

use reinhardt_query::prelude::*;

let query = Query::drop_view()
    .name("active_users")
    .if_exists();

Implementations

Source

impl DropViewStatement

pub fn new() -> Self

Create a new DROP VIEW statement

pub fn take(&mut self) -> Self

Take the ownership of data in the current DropViewStatement

pub fn name<N>(&mut self, name: N) -> &mut Self
where N: IntoIden,

Set the view name to drop

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_view()
    .name("active_users");
pub fn names<I, N>(&mut self, names: I) -> &mut Self
where I: IntoIterator<Item = N>, N: IntoIden,

Set multiple view names to drop

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_view()
    .names(vec!["view1", "view2", "view3"]);
pub fn if_exists(&mut self) -> &mut Self

Add IF EXISTS clause

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_view()
    .name("active_users")
    .if_exists();
pub fn cascade(&mut self) -> &mut Self

Add CASCADE clause

This option automatically drops dependent objects. Supported by PostgreSQL.

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_view()
    .name("active_users")
    .cascade();
pub fn restrict(&mut self) -> &mut Self

Add RESTRICT clause

This option prevents dropping if there are dependent objects (default behavior). Supported by PostgreSQL.

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_view()
    .name("active_users")
    .restrict();
pub fn materialized(&mut self, materialized: bool) -> &mut Self

Set MATERIALIZED flag (PostgreSQL only)

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_view()
    .name("active_users")
    .materialized(true);