DropSequenceStatement

Struct DropSequenceStatement 

pub struct DropSequenceStatement { /* private fields */ }
DROP SEQUENCE statement builder

This struct provides a fluent API for constructing DROP SEQUENCE queries.

Examples

use reinhardt_query::prelude::*;

// DROP SEQUENCE my_seq
let query = Query::drop_sequence()
    .name("my_seq");

// DROP SEQUENCE IF EXISTS my_seq
let query = Query::drop_sequence()
    .name("my_seq")
    .if_exists();

// DROP SEQUENCE my_seq CASCADE
let query = Query::drop_sequence()
    .name("my_seq")
    .cascade();

Implementations

Source

impl DropSequenceStatement

pub fn new() -> Self

Create a new DROP SEQUENCE statement

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_sequence();
pub fn take(&mut self) -> Self

Take the ownership of data in the current DropSequenceStatement

pub fn name<N>(&mut self, name: N) -> &mut Self
where N: IntoIden,

Set the sequence name

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_sequence()
    .name("my_seq");
pub fn if_exists(&mut self) -> &mut Self

Add IF EXISTS clause

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_sequence()
    .name("my_seq")
    .if_exists();
pub fn cascade(&mut self) -> &mut Self

Add CASCADE clause

This will also drop objects that depend on the sequence.

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_sequence()
    .name("my_seq")
    .cascade();
pub fn restrict(&mut self) -> &mut Self

Add RESTRICT clause

This will refuse to drop the sequence if any objects depend on it (default behavior).

Examples
use reinhardt_query::prelude::*;

let query = Query::drop_sequence()
    .name("my_seq")
    .restrict();