UpdateStatement

Struct UpdateStatement 

pub struct UpdateStatement { /* private fields */ }
UPDATE statement builder

This struct provides a fluent API for constructing UPDATE queries.

Examples

use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users")
    .value("active", false)
    .and_where(Expr::col("last_login").lt("2020-01-01"));

Implementations

Source

impl UpdateStatement

pub fn new() -> Self

Create a new UPDATE statement

pub fn take(&mut self) -> Self

Take the ownership of data in the current UpdateStatement

pub fn table<T>(&mut self, tbl: T) -> &mut Self
where T: IntoTableRef,

Set the table to update

Examples
use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users");
pub fn value<C, V>(&mut self, col: C, val: V) -> &mut Self
where C: IntoIden, V: IntoValue,

Set a column value

Examples
use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users")
    .value("active", false)
    .value("name", "Alice");
pub fn value_expr<C, E>(&mut self, col: C, expr: E) -> &mut Self
where C: IntoIden, E: Into<SimpleExpr>,

Set a column to an expression value

Use this method when the value is an expression (e.g., Expr::current_timestamp(), Expr::col("other_column"), Expr::cust("NULL")) rather than a plain value.

Examples
use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users")
    .value_expr("updated_at", Expr::current_timestamp())
    .value_expr("status", Expr::cust("NULL"));
pub fn values<I, C, V>(&mut self, values: I) -> &mut Self
where I: IntoIterator<Item = (C, V)>, C: IntoIden, V: IntoValue,

Set multiple column values

Examples
use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users")
    .values([
        ("name", "Alice".into()),
        ("email", "alice@example.com".into()),
    ]);
pub fn and_where<C>(&mut self, condition: C) -> &mut Self
where C: IntoCondition,

Add a condition to the WHERE clause

Examples
use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users")
    .value("active", false)
    .and_where(Expr::col("last_login").lt("2020-01-01"));
pub fn cond_where(&mut self, condition: Condition) -> &mut Self

Add a conditional WHERE clause.

This is an alias for and_where that accepts a Condition.

pub fn returning<I, C>(&mut self, cols: I) -> &mut Self
where I: IntoIterator<Item = C>, C: IntoColumnRef,

Add a RETURNING clause

Examples
use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users")
    .value("active", false)
    .and_where(Expr::col("id").eq(1))
    .returning(["id", "updated_at"]);
pub fn returning_all(&mut self) -> &mut Self

Add a RETURNING * clause

Examples
use reinhardt_query::prelude::*;

let query = Query::update()
    .table("users")
    .value("active", false)
    .and_where(Expr::col("id").eq(1))
    .returning_all();