pub enum JoinType {
Join,
InnerJoin,
LeftJoin,
RightJoin,
FullOuterJoin,
CrossJoin,
}Expand description
SQL JOIN types.
Variants
Join
INNER JOIN - returns rows when there is a match in both tables
InnerJoin
INNER JOIN (explicit)
LeftJoin
LEFT JOIN - returns all rows from the left table
RightJoin
RIGHT JOIN - returns all rows from the right table
FullOuterJoin
FULL OUTER JOIN - returns rows when there is a match in one of the tables
CrossJoin
CROSS JOIN - cartesian product of both tables
Implementations