CheckTableOption

Enum CheckTableOption 

pub enum CheckTableOption {
    ForUpgrade,
    Quick,
    Fast,
    Medium,
    Extended,
    Changed,
}
CHECK TABLE statement options (MySQL-only)

This enum represents the check option for the CHECK TABLE statement. CHECK TABLE checks a table or tables for errors.

Examples

use reinhardt_query::types::maintenance::CheckTableOption;

// Default check (MEDIUM)
let opt = CheckTableOption::default();

// Quick check
let opt = CheckTableOption::Quick;

// Extended check
let opt = CheckTableOption::Extended;

Variants



ForUpgrade

Check for version compatibility



Quick

Quick check, skip scanning rows for incorrect links



Fast

Fast check, check only tables that haven’t been closed properly



Medium

Medium check (default), scan rows to verify deleted links are valid



Extended

Extended check, do a full key lookup for all keys



Changed

Check only tables that have been changed since last check or not closed properly