RepairTableOption

Struct RepairTableOption 

pub struct RepairTableOption { /* private fields */ }
REPAIR TABLE statement options (MySQL-only)

This struct represents options for the REPAIR TABLE statement. REPAIR TABLE repairs a possibly corrupted table.

Examples

use reinhardt_query::types::maintenance::RepairTableOption;

// Basic REPAIR TABLE
let opt = RepairTableOption::new();

// REPAIR TABLE with QUICK option
let opt = RepairTableOption::new().quick(true);

// REPAIR TABLE with EXTENDED option
let opt = RepairTableOption::new().extended(true);

Implementations

Source

impl RepairTableOption

pub fn new() -> Self

Create a new REPAIR TABLE option

Examples
use reinhardt_query::types::maintenance::RepairTableOption;

let opt = RepairTableOption::new();
pub fn no_write_to_binlog(self, no_write_to_binlog: bool) -> Self

Set NO_WRITE_TO_BINLOG option

Suppresses binary logging for this operation.

Examples
use reinhardt_query::types::maintenance::RepairTableOption;

let opt = RepairTableOption::new().no_write_to_binlog(true);
pub fn local(self, local: bool) -> Self

Set LOCAL option

Suppresses binary logging for this operation (same as NO_WRITE_TO_BINLOG).

Examples
use reinhardt_query::types::maintenance::RepairTableOption;

let opt = RepairTableOption::new().local(true);
pub fn quick(self, quick: bool) -> Self

Set QUICK option

Tries to repair only the index file, not the data file.

Examples
use reinhardt_query::types::maintenance::RepairTableOption;

let opt = RepairTableOption::new().quick(true);
pub fn extended(self, extended: bool) -> Self

Set EXTENDED option

Creates the index row by row instead of creating one index at a time with sorting.

Examples
use reinhardt_query::types::maintenance::RepairTableOption;

let opt = RepairTableOption::new().extended(true);
pub fn use_frm(self, use_frm: bool) -> Self

Set USE_FRM option

Uses the table definition from the .frm file to recreate the index file.

Examples
use reinhardt_query::types::maintenance::RepairTableOption;

let opt = RepairTableOption::new().use_frm(true);