pub struct OrderExpr {
pub expr: OrderExprKind,
pub order: Order,
pub nulls: Option<NullOrdering>,
}Expand description
An expression with its ordering specification.
This represents a single item in an ORDER BY clause.
Fields
expr: OrderExprKindThe expression to order by (column or expression)
order: OrderThe ordering direction
nulls: Option<NullOrdering>Optional NULL ordering
Implementations
Sourceimpl OrderExpr
impl OrderExpr
Sourcepub fn new<I: IntoIden>(column: I) -> Self
pub fn new<I: IntoIden>(column: I) -> Self
Create a new order expression for a column with the default order (ASC).
Sourcepub fn new_table_column<T: IntoIden, C: IntoIden>(table: T, column: C) -> Self
pub fn new_table_column<T: IntoIden, C: IntoIden>(table: T, column: C) -> Self
Create a new order expression for a qualified column.
Sourcepub fn nulls(self, nulls: NullOrdering) -> Self
pub fn nulls(self, nulls: NullOrdering) -> Self
Set NULL ordering.