pub struct DropSequenceStatement { /* private fields */ }Expand description
DROP SEQUENCE statement builder
This struct provides a fluent API for constructing DROP SEQUENCE queries.
Examples
use reinhardt_query::prelude::*;
// DROP SEQUENCE my_seq
let query = Query::drop_sequence()
.name("my_seq");
// DROP SEQUENCE IF EXISTS my_seq
let query = Query::drop_sequence()
.name("my_seq")
.if_exists();
// DROP SEQUENCE my_seq CASCADE
let query = Query::drop_sequence()
.name("my_seq")
.cascade();Implementations
Sourceimpl DropSequenceStatement
impl DropSequenceStatement
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new DROP SEQUENCE statement
Examples
use reinhardt_query::prelude::*;
let query = Query::drop_sequence();Sourcepub fn take(&mut self) -> Self
pub fn take(&mut self) -> Self
Take the ownership of data in the current DropSequenceStatement
Sourcepub fn name<N>(&mut self, name: N) -> &mut Selfwhere
N: IntoIden,
pub fn name<N>(&mut self, name: N) -> &mut Selfwhere
N: IntoIden,
Set the sequence name
Examples
use reinhardt_query::prelude::*;
let query = Query::drop_sequence()
.name("my_seq");Sourcepub fn if_exists(&mut self) -> &mut Self
pub fn if_exists(&mut self) -> &mut Self
Add IF EXISTS clause
Examples
use reinhardt_query::prelude::*;
let query = Query::drop_sequence()
.name("my_seq")
.if_exists();Trait Implementations
Sourceimpl Clone for DropSequenceStatement
impl Clone for DropSequenceStatement
Sourcefn clone(&self) -> DropSequenceStatement
fn clone(&self) -> DropSequenceStatement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DropSequenceStatement
impl Debug for DropSequenceStatement
Sourceimpl Default for DropSequenceStatement
impl Default for DropSequenceStatement
Sourceimpl QueryStatementBuilder for DropSequenceStatement
impl QueryStatementBuilder for DropSequenceStatement
Sourcefn build_any(&self, query_builder: &dyn QueryBuilderTrait) -> (String, Values)
fn build_any(&self, query_builder: &dyn QueryBuilderTrait) -> (String, Values)
Build SQL statement for a database backend and collect query parameters Read more
impl QueryStatementWriter for DropSequenceStatement