pub struct UpdateStatement { /* private fields */ }Expand description
Implementations
Sourceimpl UpdateStatement
impl UpdateStatement
Sourcepub fn take(&mut self) -> Self
pub fn take(&mut self) -> Self
Take the ownership of data in the current UpdateStatement
Sourcepub fn table<T>(&mut self, tbl: T) -> &mut Selfwhere
T: IntoTableRef,
pub fn table<T>(&mut self, tbl: T) -> &mut Selfwhere
T: IntoTableRef,
Sourcepub fn value_expr<C, E>(&mut self, col: C, expr: E) -> &mut Self
pub fn value_expr<C, E>(&mut self, col: C, expr: E) -> &mut Self
Set a column to an expression value
Use this method when the value is an expression (e.g., Expr::current_timestamp(),
Expr::col("other_column"), Expr::cust("NULL")) rather than a plain value.
Examples
ⓘ
use reinhardt_query::prelude::*;
let query = Query::update()
.table("users")
.value_expr("updated_at", Expr::current_timestamp())
.value_expr("status", Expr::cust("NULL"));Sourcepub fn and_where<C>(&mut self, condition: C) -> &mut Selfwhere
C: IntoCondition,
pub fn and_where<C>(&mut self, condition: C) -> &mut Selfwhere
C: IntoCondition,
Sourcepub fn cond_where(&mut self, condition: Condition) -> &mut Self
pub fn cond_where(&mut self, condition: Condition) -> &mut Self
Sourcepub fn returning<I, C>(&mut self, cols: I) -> &mut Selfwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
pub fn returning<I, C>(&mut self, cols: I) -> &mut Selfwhere
I: IntoIterator<Item = C>,
C: IntoColumnRef,
Sourcepub fn returning_all(&mut self) -> &mut Self
pub fn returning_all(&mut self) -> &mut Self